@@ -28,18 +28,16 @@
 
 #include "peerinfo.h"
 
-#include <libtorrent/version.hpp>
-
 #include <QBitArray>
 
-#include "base/bittorrent/torrenthandle.h"
+#include "base/bittorrent/torrent.h"
 #include "base/net/geoipmanager.h"
 #include "base/unicodestrings.h"
 #include "peeraddress.h"
 
 using namespace BitTorrent;
 
-PeerInfo::PeerInfo(const TorrentHandle *torrent, const lt::peer_info &nativeInfo)
+PeerInfo::PeerInfo(const Torrent *torrent, const lt::peer_info &nativeInfo)
     : m_nativeInfo(nativeInfo)
 {
     calcRelevance(torrent);
@@ -61,12 +59,12 @@ bool PeerInfo::fromLSD() const
     return static_cast<bool>(m_nativeInfo.source & lt::peer_info::lsd);
 }
 
-#ifndef DISABLE_COUNTRIES_RESOLUTION
 QString PeerInfo::country() const
 {
-    return Net::GeoIPManager::instance()->lookup(address().ip);
+    if (m_country.isEmpty())
+        m_country = Net::GeoIPManager::instance()->lookup(address().ip);
+    return m_country;
 }
-#endif
 
 bool PeerInfo::isInteresting() const
 {
@@ -209,15 +207,10 @@ qlonglong PeerInfo::totalDownload() const
 
 QBitArray PeerInfo::pieces() const
 {
-#if (LIBTORRENT_VERSION_NUM < 10200)
-    using PieceIndex = int;
-#else
-    using PieceIndex = lt::piece_index_t;
-#endif
-
     QBitArray result(m_nativeInfo.pieces.size());
-    for (int i = 0; i < result.size(); ++i) {
-        if (m_nativeInfo.pieces[PieceIndex {i}])
+    for (int i = 0; i < result.size(); ++i)
+    {
+        if (m_nativeInfo.pieces[lt::piece_index_t {i}])
             result.setBit(i, true);
     }
     return result;
@@ -228,20 +221,12 @@ QString PeerInfo::connectionType() const
     if (m_nativeInfo.flags & lt::peer_info::utp_socket)
         return QString::fromUtf8(C_UTP);
 
-    QString connection;
-    switch (m_nativeInfo.connection_type) {
-    case lt::peer_info::http_seed:
-    case lt::peer_info::web_seed:
-        connection = "Web";
-        break;
-    default:
-        connection = "BT";
-    }
-
-    return connection;
+    return (m_nativeInfo.connection_type == lt::peer_info::standard_bittorrent)
+        ? QLatin1String {"BT"}
+        : QLatin1String {"Web"};
 }
 
-void PeerInfo::calcRelevance(const TorrentHandle *torrent)
+void PeerInfo::calcRelevance(const Torrent *torrent)
 {
     const QBitArray allPieces = torrent->pieces();
     const QBitArray peerPieces = pieces();
@@ -249,8 +234,10 @@ void PeerInfo::calcRelevance(const TorrentHandle *torrent)
     int localMissing = 0;
     int remoteHaves = 0;
 
-    for (int i = 0; i < allPieces.size(); ++i) {
-        if (!allPieces[i]) {
+    for (int i = 0; i < allPieces.size(); ++i)
+    {
+        if (!allPieces[i])
+        {
             ++localMissing;
             if (peerPieces[i])
                 ++remoteHaves;
@@ -270,14 +257,17 @@ qreal PeerInfo::relevance() const
 
 void PeerInfo::determineFlags()
 {
-    if (isInteresting()) {
+    if (isInteresting())
+    {
         // d = Your client wants to download, but peer doesn't want to send (interested and choked)
-        if (isRemoteChocked()) {
+        if (isRemoteChocked())
+        {
             m_flags += "d ";
             m_flagsDescription += ("d = "
                 + tr("Interested(local) and Choked(peer)") + '\n');
         }
-        else {
+        else
+        {
             // D = Currently downloading (interested and not choked)
             m_flags += "D ";
             m_flagsDescription += ("D = "
@@ -285,14 +275,17 @@ void PeerInfo::determineFlags()
         }
     }
 
-    if (isRemoteInterested()) {
+    if (isRemoteInterested())
+    {
         // u = Peer wants your client to upload, but your client doesn't want to (interested and choked)
-        if (isChocked()) {
+        if (isChocked())
+        {
             m_flags += "u ";
             m_flagsDescription += ("u = "
                 + tr("interested(peer) and choked(local)") + '\n');
         }
-        else {
+        else
+        {
             // U = Currently uploading (interested and not choked)
             m_flags += "U ";
             m_flagsDescription += ("U = "
@@ -301,69 +294,80 @@ void PeerInfo::determineFlags()
     }
 
     // O = Optimistic unchoke
-    if (optimisticUnchoke()) {
+    if (optimisticUnchoke())
+    {
         m_flags += "O ";
         m_flagsDescription += ("O = " + tr("optimistic unchoke") + '\n');
     }
 
     // S = Peer is snubbed
-    if (isSnubbed()) {
+    if (isSnubbed())
+    {
         m_flags += "S ";
         m_flagsDescription += ("S = " + tr("peer snubbed") + '\n');
     }
 
     // I = Peer is an incoming connection
-    if (!isLocalConnection()) {
+    if (!isLocalConnection())
+    {
         m_flags += "I ";
         m_flagsDescription += ("I = " + tr("incoming connection") + '\n');
     }
 
     // K = Peer is unchoking your client, but your client is not interested
-    if (!isRemoteChocked() && !isInteresting()) {
+    if (!isRemoteChocked() && !isInteresting())
+    {
         m_flags += "K ";
         m_flagsDescription += ("K = "
             + tr("not interested(local) and unchoked(peer)") + '\n');
     }
 
     // ? = Your client unchoked the peer but the peer is not interested
-    if (!isChocked() && !isRemoteInterested()) {
+    if (!isChocked() && !isRemoteInterested())
+    {
         m_flags += "? ";
         m_flagsDescription += ("? = "
             + tr("not interested(peer) and unchoked(local)") + '\n');
     }
 
     // X = Peer was included in peerlists obtained through Peer Exchange (PEX)
-    if (fromPeX()) {
+    if (fromPeX())
+    {
         m_flags += "X ";
         m_flagsDescription += ("X = " + tr("peer from PEX") + '\n');
     }
 
     // H = Peer was obtained through DHT
-    if (fromDHT()) {
+    if (fromDHT())
+    {
         m_flags += "H ";
         m_flagsDescription += ("H = " + tr("peer from DHT") + '\n');
     }
 
     // E = Peer is using Protocol Encryption (all traffic)
-    if (isRC4Encrypted()) {
+    if (isRC4Encrypted())
+    {
         m_flags += "E ";
         m_flagsDescription += ("E = " + tr("encrypted traffic")  + '\n');
     }
 
     // e = Peer is using Protocol Encryption (handshake)
-    if (isPlaintextEncrypted()) {
+    if (isPlaintextEncrypted())
+    {
         m_flags += "e ";
         m_flagsDescription += ("e = " + tr("encrypted handshake") + '\n');
     }
 
     // P = Peer is using uTorrent uTP
-    if (useUTPSocket()) {
+    if (useUTPSocket())
+    {
         m_flags += "P ";
         m_flagsDescription += ("P = " + QString::fromUtf8(C_UTP) + '\n');
     }
 
     // L = Peer is local
-    if (fromLSD()) {
+    if (fromLSD())
+    {
         m_flags += "L ";
         m_flagsDescription += ("L = " + tr("peer from LSD") + '\n');
     }
