@@ -26,27 +26,24 @@
  * exception statement from your version.
  */
 
-#ifndef QBT_GUI_FSPATHEDIT_P_H
-#define QBT_GUI_FSPATHEDIT_P_H
+#pragma once
 
-#include <QAction>
 #include <QComboBox>
-#include <QCompleter>
-#include <QContextMenuEvent>
 #include <QFileIconProvider>
-#include <QFileSystemModel>
-#include <QKeyEvent>
 #include <QLineEdit>
-#include <QMenu>
-#include <QStringRef>
+#include <QtContainerFwd>
 #include <QValidator>
-#include <QVector>
 
-class QStringList;
+class QAction;
+class QCompleter;
+class QContextMenuEvent;
+class QFileSystemModel;
+class QKeyEvent;
+class QStringRef;
 
 namespace Private
 {
-    class FileSystemPathValidator : public QValidator
+    class FileSystemPathValidator final : public QValidator
     {
         Q_OBJECT
 
@@ -112,7 +109,7 @@ namespace Private
         virtual QWidget *widget() = 0;
     };
 
-    class FileLineEdit : public QLineEdit, public FileEditorWithCompletion
+    class FileLineEdit final : public QLineEdit, public FileEditorWithCompletion
     {
         Q_OBJECT
         Q_DISABLE_COPY(FileLineEdit)
@@ -142,7 +139,7 @@ namespace Private
         QAction *m_warningAction;
     };
 
-    class FileComboEdit : public QComboBox, public FileEditorWithCompletion
+    class FileComboEdit final : public QComboBox, public FileEditorWithCompletion
     {
         Q_OBJECT
 
@@ -159,5 +156,3 @@ namespace Private
         QString text() const;
     };
 }
-
-#endif // QBT_GUI_FSPATHEDIT_P_H
